==> schedwiclnt-0.1.0.tar.gz: schedwiclnt-0.1.0/src/env_utils.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain
     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
     
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Library General Public License for more details.
     
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/*
 * env_utils.h -- Environment array management functions
 *
 * The environment array is an array of strings.  By convention these strings
 * have the form `name=value'.  This array is embedded in the environment_t
 * structure but can be used directly by system functions like exec.
 */

#ifndef _ENV_UTILS_H
#define _ENV_UTILS_H

#include <schedwi.h>

#if STDC_HEADERS || HAVE_STRING_H
#include <string.h>
#elif HAVE_STDDEF_H
#include <stddef.h>
#endif

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

struct env_str {
	char **env;
	int length;
	int idx;
};

typedef struct env_str environment_t;

extern void init_environment OF((environment_t *e));
extern void destroy_environment OF((environment_t *e));
extern int add_env_s OF((	environment_t *e,
				const char *key, size_t key_len,
				const char *val, size_t val_len));
extern int add_env OF((environment_t *e, const char *key, const char *val));
extern int search_environment OF((	environment_t *e,
					const char *var, size_t var_len));
extern const char *getvar_environment OF((environment_t *e, int idx));
extern int concat_env OF((environment_t *dst, environment_t *src));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* env_utils.h */

/*-----------------============== End Of File ==============-----------------*/

==> schedwiclnt-0.1.1.tar.gz: schedwiclnt-0.1.1/src/env_utils.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain
     
   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
 * env_utils.h -- Environment array management functions
 *
 * The environment array is an array of strings.  By convention these strings
 * have the form `name=value'.  This array is embedded in the environment_t
 * structure but can be used directly by system functions like exec.
 */

#ifndef _ENV_UTILS_H
#define _ENV_UTILS_H

#include <schedwi.h>

#if STDC_HEADERS || HAVE_STRING_H
#include <string.h>
#elif HAVE_STDDEF_H
#include <stddef.h>
#endif

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

struct env_str {
	char **env;
	int length;
	int idx;
};

typedef struct env_str environment_t;

extern void init_environment OF((environment_t *e));
extern void destroy_environment OF((environment_t *e));
extern int add_env_s OF((	environment_t *e,
				const char *key, size_t key_len,
				const char *val, size_t val_len));
extern int add_env OF((environment_t *e, const char *key, const char *val));
extern int search_environment OF((	environment_t *e,
					const char *var, size_t var_len));
extern const char *getvar_environment OF((environment_t *e, int idx));
extern int concat_env OF((environment_t *dst, environment_t *src));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* env_utils.h */

/*-----------------============== End Of File ==============-----------------*/
